@@ -13,6 +13,7 @@
 ##############################################################################
 import asyncore
 import errno
+import json
 import sys
 import threading
 import logging
@@ -52,7 +53,7 @@ class Delay:
 
     def error(self, exc_info):
         self.sent = 'error'
-        log("Error raised in delayed method", logging.ERROR, exc_info=True)
+        log("Error raised in delayed method", logging.ERROR, exc_info=exc_info)
         self.conn.return_error(self.msgid, *exc_info[:2])
 
     def __repr__(self):
@@ -84,6 +85,7 @@ class MTDelay(Delay):
 
     def error(self, exc_info):
         self.ready.wait()
+        log("Error raised in delayed method", logging.ERROR, exc_info=exc_info)
         self.conn.call_from_thread(Delay.error, self, exc_info)
 
 # PROTOCOL NEGOTIATION
@@ -630,8 +632,13 @@ class ManagedServerConnection(Connection):
         self.message_output(self.current_protocol)
 
     def recv_handshake(self, proto):
-        Connection.recv_handshake(self, proto)
-        self.obj.notifyConnected(self)
+        if proto == 'ruok':
+            self.message_output(json.dumps(self.mgr.ruok()))
+            self.poll()
+            Connection.close(self)
+        else:
+            Connection.recv_handshake(self, proto)
+            self.obj.notifyConnected(self)
 
     def close(self):
         self.obj.notifyDisconnected()
